#!/usr/bin/env python<PYVERSION>
# -*- coding: utf-8; mode: python; -*-
<LICENSE_HEADER>
"""Command-line Callable"""

def main():
    return 0


if __name__ == '__main__':
    main()
